@@ -7,6 +7,11 @@ use strict;
 use warnings;
 use Carp qw(confess);
 
+BEGIN {
+	Filter::Util::Call::filter_add(\&OOPS::SelfFilter::filter)
+		unless $OOPS::SelfFilter::defeat;
+}
+
 sub initialize
 {
 	my $oops = shift;
@@ -66,7 +71,7 @@ sub tabledefs
 	CREATE TABLE TP_big (
 		id		BIGINT NOT NULL, 
 		pkey		BYTEA,
-		pval		TEXT,
+		pval		BYTEA,
 		PRIMARY KEY (id, pkey));
 
 	CREATE TABLE TP_counters (
@@ -121,8 +126,11 @@ sub query
 
 	my $query;
 	confess unless $query = $oops->{queries}{$q};
+
 	$query =~ s/TP_/$oops->{table_prefix}/g;
 
+	$oops->query_debug('pg', $q, %args);
+
 	my $dbh = $args{dbh} || $oops->{dbh};
 	my $sth = $dbh->prepare_cached($query, undef, 3) || die $dbh->errstr;
 
@@ -133,6 +141,7 @@ sub query
 				: $args{execute})
 			: ();
 
+		my $e;
 		if ($oops->{binary_params}{$q}) {
 			for (my $i = 0; $i <= $#a; $i++) {
 				if ($oops->{binary_params}{$q}[$i+1]) {
@@ -142,9 +151,13 @@ sub query
 					$sth->bind_param($i+1, $a[$i]);
 				}
 			}
-			$sth->execute() || confess "could not execute '$query' with '@a':".$sth->errstr;
+			$sth->execute() or $e = "Could Not Execute '$query' with '@a':" . ($sth->errstr);
 		} else {
-			$sth->execute(@a) || confess "could not execute '$query' with '@a':".$sth->errstr;
+			$sth->execute(@a) or $e = "could not execute '$query' with '@a':".$sth->errstr;
+		}
+		if ($e) {
+			$e =~ s/\n/\\n /g; # debug
+			confess($e);
 		}
 	}
 
